@@ -27,20 +27,6 @@ $(".docs-sidebar-section ol > li > a").click(function () {
 
 $('ol > li:has(ul)').addClass('docs-has-sub');
 
-// Needed for code and pre
-$(function() {
-    var pre = document.getElementsByTagName('pre'),
-        pl = pre.length;
-    for (var i = 0; i < pl; i++) {
-        pre[i].innerHTML = '<span class="line-number"></span>' + pre[i].innerHTML + '<span class="cl"></span>';
-        var num = pre[i].innerHTML.split(/\n/).length;
-        for (var j = 0; j < num; j++) {
-            var line_num = pre[i].getElementsByTagName('span')[0];
-            line_num.innerHTML += '<span aria-hidden="true">' + (j + 1) + '</span>';
-        }
-    }
-});
-
 // webui popover
 $(document).ready(function() {
     function checkWidth() {
